package com.example.mykafkaproject.server;

import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson2.JSON;
import com.dahuatech.hutool.http.Method;
import com.dahuatech.hutool.json.JSONObject;
import com.dahuatech.hutool.json.JSONUtil;
import com.dahuatech.icc.exception.ClientException;
import com.dahuatech.icc.oauth.http.DefaultClient;
import com.dahuatech.icc.oauth.http.IClient;
import com.dahuatech.icc.oauth.model.v202010.GeneralRequest;
import com.dahuatech.icc.oauth.model.v202010.GeneralResponse;
import com.example.mykafkaproject.bean.WarnPushBase;
import com.example.mykafkaproject.mapper.WarnPushBaseMapper;
import com.example.mykafkaproject.utils.HttpUtils;
import com.example.mykafkaproject.utils.JsonUtil;
import com.example.mykafkaproject.utils.PinYinUtil;
import com.example.mykafkaproject.utils.RtspToMP4;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Service("WarnPushBaseServer")
public class WarnPushBaseServer {

    private static final Logger LOGGER = LoggerFactory.getLogger(WarnPushBaseServer.class);

    @Autowired
    WarnPushBaseMapper warnPushBaseMapper;

    @Autowired
    private RtspToMP4 rtspToMP4;


    public void addMessage(String message) {
        LOGGER.info("预警信息：" + message);
        WarnPushBase warnPushBase = JSON.parseObject(message, WarnPushBase.class);
//        if("乌海矿".equals(warnPushBase.getBelong())){
        //获取视频地址 先不截取布控球的视频
            String video;
        if(!warnPushBase.getAlarmDeviceName().contains("布控球")){
            //获取前后五秒时间戳
            Date alarmTime = warnPushBase.getAlarmTime();
            video = getVideo(warnPushBase.getChannelId(), alarmTime.getTime() / 1000 - 3, alarmTime.getTime() / 1000 + 3);
        }else{
             video = "http://172.16.20.211:8080/profile/MP4/1001952$1$0$0_1698988966.mp4";
        }

//        String video ="F:\\ruoyi\\uploadPath\\MP4";
        warnPushBase.setAlarmMsg(warnPushBase.getGradeType());
        warnPushBase.setGradeType(warnPushBase.getGradeType());
        warnPushBase.setVideo(video);
        warnPushBaseMapper.add(warnPushBase);

        //发送iot的http请求
        iotPush(warnPushBase);
//        }
    }

    public String getVideo(String channelId, Long startTime, Long endTime) {
        try {
            //获取录像视频流地址
            String url = rtsp1(channelId, startTime, endTime);

            //录像视频流转mp4文件
            final Process[] process = new Process[1];
            final String fileName = channelId + "_" + startTime + ".mp4";
            new Thread(new Runnable() {
                @Override
                public void run() {
                    process[0] = rtspToMP4.StartRecord("F:\\ffmpeg\\ffmpeg-2023-10-29-git-2532e832d2-full_build\\bin\\ffmpeg.exe"
                            , url, "F:\\ruoyi\\uploadPath\\MP4\\" + fileName);
                }
            }).start();


            Thread.sleep(6 * 1000);

            rtspToMP4.stopRecord(process[0]);

            return "http://172.16.20.211:8080/profile/MP4/" + fileName;
        } catch (ClientException e) {
            e.printStackTrace();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        return "录像错误";
    }


    public String rtsp1(String channelId, Long startTime, Long endTime) throws ClientException {
        IClient iClient = new DefaultClient();
        GeneralRequest generalRequest =
                new GeneralRequest("/evo-apigw/admin/API/SS/Playback/StartPlaybackByTime", Method.POST);
        String body =
                "{\n" +
                        "  \"data\": {\n" +
                        "    \"channelId\": \"" + channelId + "\",\n" +
                        "    \"recordSource\": \"3\",\n" +
                        "    \"startTime\": \"" + startTime + "\",\n" +
                        "    \"endTime\": \"" + endTime + "\",\n" +
                        "    \"streamType\": \"1\",\n" +
                        "    \"recordType\": \"1\"\n" +
                        "  }\n" +
                        "}";
        generalRequest.body(body);
        GeneralResponse response = iClient.doAction(generalRequest, generalRequest.getResponseClass());
        String result = response.getResult();
        JSONObject obj = JSONUtil.parseObj(response.getResult());
        String url = obj.getJSONObject("data").getStr("url");
        String token = obj.getJSONObject("data").getStr("token");
        String[] parts = url.split("\\|");
        return parts[0] + "?token=" + token + "&trackID=0";
    }


    public void iotPush(WarnPushBase warnPushBase) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String url = "http://172.16.20.170:8089/api/v1/aqgl/warn";
        String result_info = null;
        try {
            //同步IOT
            Map<String, String> bodys = new HashMap<>();
            bodys.put("order_name", "AI预警平台");
            bodys.put("alarm_device_name", warnPushBase.getAlarmDeviceName());
            bodys.put("grade_name", warnPushBase.getGradeName());
            bodys.put("grade_type", warnPushBase.getGradeType());
            bodys.put("grade_type_code", PinYinUtil.getPinYinHeadChar(warnPushBase.getGradeType()));
            bodys.put("alarm_time", simpleDateFormat.format(warnPushBase.getAlarmTime()));
            bodys.put("alarm_msg", warnPushBase.getAlarmMsg());
            bodys.put("picture", warnPushBase.getPicture());
            bodys.put("mine", warnPushBase.getBelong());
            bodys.put("video",warnPushBase.getVideo());
            bodys.put("channel_id",warnPushBase.getChannelId());
            bodys.put("create_time", simpleDateFormat.format(new Date()));
            result_info = HttpUtils.doPostJson(url, null, JsonUtil.getObjectToString(bodys));
        } catch (Exception e) {
            System.out.println("同步IOT出错！！！");
        }
        System.out.println("IOT返回结果：" + result_info);
    }


}


